{ config, pkgs, ... }:
{
  imports = [
    ./hardware-configuration.nix
    ../../../modules/common_vm.nix
  ];

  age.secrets = {
    smtpPassword = {
      file = ../../../secrets/de-dus01/gitea/smtp_password.age;
      owner = "git";
      group = "git";
    };
  };

  boot.loader.grub.enable = true;
  boot.loader.grub.device = "/dev/sda";
  boot.loader.grub.useOSProber = true;

  networking.hostName = "gitea";
  networking.firewall.allowedTCPPorts = [ 3000 ];

  services.mysql = {
    enable = true;
    package = pkgs.mariadb;
    ensureDatabases = [ "gitea" ];
    ensureUsers = [{
      name = "git";
      ensurePermissions = {
        "gitea.*" = "ALL PRIVILEGES";
      };
    }];
  };

  services.gitea = {
    enable = true;
    user = "git";
    group = "git";
    package = pkgs.unstable.gitea;
    appName = "obscuresecure.dev git";
    lfs.enable = true;
    database = {
      type = "mysql";
      socket = "/var/run/mysqld/mysqld.sock";
      name = "gitea";
      user = "git";
    };
    settings = {
      server = {
        DOMAIN = "git.obscuresecure.dev";
        HTTP_ADDR = "::";
        ROOT_URL = "https://git.obscuresecure.dev/";
        DISABLE_SSH = false;
        SSH_PORT = 22;
        SSH_USER = "git";
        SSH_DOMAIN = "ssh.git.obscuresecure.dev";
        SSH_AUTHORIZED_KEYS_COMMAND_TEMPLATE = "{{.AppPath}} --config={{.CustomConf}} --work-path /tmp/gitea serv key-{{.Key.ID}}";
      };
      actions = {
        ENABLED = true;
      };
      #mailer = {
      #  ENABLED = "true";
      #  PROTOCOL = "smtps";
      #  SMTP_ADDR = "mx1.zettoit.eu";
      #  USER = "git@zettoit.eu";
      #  FROM = "git@zettoit.eu";
      #};
      metrics = {
        ENABLED = "true";
      };
    };
    mailerPasswordFile = config.age.secrets.smtpPassword.path;
  };

  users.users.git = {
    description = "Gitea Service";
    home = config.services.gitea.stateDir;
    useDefaultShell = true;
    group = "git";
    isSystemUser = true;
    uid = 992;
  };
  users.groups.git = {
    gid = 991;
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?
}
